@@ -25,29 +25,17 @@
 
 using namespace Akonadi;
 
-namespace Akonadi
-{
-class KColumnFilterProxyModelPrivate
-{
-public:
-    QVector<int> m_visibleColumns;
-};
-}
-
 KColumnFilterProxyModel::KColumnFilterProxyModel(QObject *parent)
     : QSortFilterProxyModel(parent)
-    , d_ptr(new KColumnFilterProxyModelPrivate)
 { }
 
 KColumnFilterProxyModel::~KColumnFilterProxyModel()
 {
-    delete d_ptr;
 }
 
 QVector<int> KColumnFilterProxyModel::visbileColumns() const
 {
-    Q_D(const KColumnFilterProxyModel);
-    return d->m_visibleColumns;
+    return m_visibleColumns;
 }
 
 void KColumnFilterProxyModel::setVisibleColumn(int column)
@@ -57,16 +45,14 @@ void KColumnFilterProxyModel::setVisibleColumn(int column)
 
 void KColumnFilterProxyModel::setVisibleColumns(const QVector<int> &visibleColumns)
 {
-    Q_D(KColumnFilterProxyModel);
-    d->m_visibleColumns = visibleColumns;
+    m_visibleColumns = visibleColumns;
     invalidateFilter();
 }
 
 bool KColumnFilterProxyModel::filterAcceptsColumn(int column, const QModelIndex &parent) const
 {
-    Q_D(const KColumnFilterProxyModel);
 
-    if (!d->m_visibleColumns.isEmpty() && !d->m_visibleColumns.contains(column)) {
+    if (!m_visibleColumns.isEmpty() && !m_visibleColumns.contains(column)) {
         // We only filter columns out when m_visibleColumns actually contains values.
         return false;
     }
